Learn R Programming

spacefillr (version 0.4.0)

generate_halton_faure_single: Generate Halton Value (Faure Initialized)

Description

Generate a single value from a seeded Halton set, initialized with a Faure sequence.

Note: This is much slower than generating the entire set ahead of time.

Usage

generate_halton_faure_single(i, dim)

Value

A single numeric value representing the `i`th element in the `dim` dimension.

Arguments

i

The element of the sequence to extract.

dim

The dimension of the sequence to extract.

Examples

Run this code
#Generate a 3D sample:
point3d = c(generate_halton_faure_single(10, dim = 1),
           generate_halton_faure_single(10, dim = 2),
           generate_halton_faure_single(10, dim = 3))
point3d

Run the code above in your browser using DataLab