Learn R Programming

spacefillr (version 0.4.0)

generate_halton_random_set: Generate Halton Set (Randomly Initialized)

Description

Generate a set of values from a seeded Halton set.

Usage

generate_halton_random_set(n, dim, seed = 0)

Value

An `n` x `dim` matrix listing all the

Arguments

n

The number of values (per dimension) to extract.

dim

The number of dimensions of the sequence.

seed

Default `0`. The random seed.

Examples

Run this code
#Generate a 2D sample:
points2d = generate_halton_random_set(n=1000, dim=2)
plot(points2d)

#Change the seed and extract a separate pair of dimensions
points2d = generate_halton_random_set(n=1000, dim=10,seed=2)
plot(points2d[,5:6])

#Integrate the value of pi by counting the number of randomly generated points that fall
#within the unit circle.
pointset = matrix(generate_halton_random_set(10000,dim=2),ncol=2)

pi_estimate = 4*sum(pointset[,1] * pointset[,1] + pointset[,2] * pointset[,2] < 1)/10000
pi_estimate

Run the code above in your browser using DataLab