powered by
Generate a single value from a seeded Halton set, initialized with a Faure sequence.
Note: This is much slower than generating the entire set ahead of time.
generate_halton_faure_single(i, dim)
A single numeric value representing the `i`th element in the `dim` dimension.
The element of the sequence to extract.
The dimension of the sequence to extract.
#Generate a 3D sample: point3d = c(generate_halton_faure_single(10, dim = 1), generate_halton_faure_single(10, dim = 2), generate_halton_faure_single(10, dim = 3)) point3d
Run the code above in your browser using DataLab